Conditional class

Conditional rendering class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

list({required BuildContext context, required bool conditionBuilder(BuildContext context), required List<Widget> widgetBuilder(BuildContext context), List<Widget> fallbackBuilder(BuildContext context)?}) → List<Widget>
A function which returns a List<Widget>
single({required BuildContext context, required bool conditionBuilder(BuildContext context), required Widget widgetBuilder(BuildContext context), Widget fallbackBuilder(BuildContext context)?}) → Widget
A function which returns a single Widget